diff src/gtkpounce.h @ 5907:18486c860a46

[gaim-migrate @ 6339] Added an Add Buddy Pounce menu item to the conversation window. committer: Tailor Script <tailor@pidgin.im>
author Christian Hammond <chipx86@chipx86.com>
date Mon, 16 Jun 2003 21:43:43 +0000
parents 448f2f4ca3ec
children fa6395637e2c
line wrap: on
line diff
--- a/src/gtkpounce.h	Mon Jun 16 05:14:05 2003 +0000
+++ b/src/gtkpounce.h	Mon Jun 16 21:43:43 2003 +0000
@@ -28,10 +28,12 @@
 /**
  * Displays a New Buddy Pounce or Edit Buddy Pounce dialog.
  *
  * @param buddy      The optional buddy to pounce on.
  * @param cur_pounce The current buddy pounce, if editting an existing one.
  */
-void gaim_gtkpounce_dialog_show(struct buddy *buddy, GaimPounce *cur_pounce);
+void gaim_gtkpounce_dialog_show(GaimAccount *account, const char *name,
+								GaimPounce *cur_pounce);
 
 /**
  * Displays all registered buddy pounces in a menu.
@@ -28,10 +28,12 @@
  * Displays a New Buddy Pounce or Edit Buddy Pounce dialog.
  *
- * @param buddy      The optional buddy to pounce on.
+ * @param account    The optional account to use.
+ * @param name       The optional name to pounce on.
  * @param cur_pounce The current buddy pounce, if editting an existing one.
  */